==> v3.4.9.tar.gz: bookmarks/l10n/sv.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Bokmärken",
    "You bookmarked \"%s\"" : "Du sparade \"%s\"",
    "%1$s bookmarked \"%2$s\"" : "%1$s sparade \"%2$s\"",
    "Someone bookmarked \"%s\"" : "Någon sparade %s",
    "You deleted \"%s\"" : "Du raderade \"%s\"",
    "%1$s deleted \"%2$s\"" : "%1$s raderade \"%2$s\"",
    "Someone deleted \"%s\"" : "Någon raderade \"%s\"",
    "You created folder \"%s\"" : "Du skapade mappen \"%s\"",
    "%1$s created folder \"%2$s\"" : "%1$s skapade mappen \"%2$s\"",
    "Someone created folder \"%s\"" : "Någon skapade mappen \"%s\"",
    "You moved folder \"%s\"" : "Du flyttade mappen \"%s\"",
    "%1$s moved folder \"%2$s\"" : "%1$s flyttade mappen \"%2$s\"",
    "Someone moved folder \"%s\"" : "Någon flyttade mappen \"%s\"",
    "You deleted folder \"%s\"" : "Du raderade mappen \"%s\"",
    "%1$s deleted folder \"%2$s\"" : "%1$s raderade mappen \"%2$s\"",
    "Someone deleted folder \"%s\"" : "Någon raderade mappen \"%s\"",
    "You shared folder \"%1$s\" with %2$s" : "Du delade mappen \"%1$s\" med %2$s",
    "You shared folder \"%s\" with someone" : "Du delade mappen \"%s\" med någon",
    "%1$s shared folder \"%2$s\" with you" : "%1$s delade mappen \"%2$s\" med dig",
    "Someone shared folder \"%s\" with you" : "Någon delade mappen \"%s\" med dig",
    "You unshared folder \"%1$s\" with %2$s" : "Du slutade dela mappen \"%1$s\" med %2$s",
    "You unshared folder \"%s\" with someone" : "Du slutade dela mappen \"%s\" med någon",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s slutade dela mappen \"%2$s\" med dig",
    "Someone unshared folder \"%s\" with you" : "Någon slutade  dela mappen \"%s\" med dig",
    "No file provided for import" : "Inga filer given för importering",
    "Unsupported file type for import" : "Ogiltig filtyp för import",
    "Bookmarks shared by %s" : "Bokmärken delas av %s",
    "Bookmark" : "Bokmärke",
    "Bookmark deleted" : "Bokmärke raderat",
    "Bookmark created" : "Bokmärke skapat",
    "Bookmark moved" : "Bokmärke flyttat",
    "Bookmark updated" : "Bokmärke uppdaterat",
    "Create bookmark" : "Skapa bokmärke",
    "Takes a link and adds it to your collection of bookmarks." : "Tar en länk och lägger till den i dina bokmärken.",
    "A Bookmark manager for Nextcloud" : "En bokmärkeshanterare för Nextcloud",
    "Enter new title" : "Ange ny titel",
    "Select bookmark" : "Välj bokmärke",
    "Details" : "Detaljer",
    "Rename" : "Byt namn",
    "Move" : "Flytta",
    "Delete" : "Radera",
    "Select one or more tags" : "Välj en eller flera taggar",
    "New" : "Nytt",
    "New bookmark" : "Nytt bokmärke",
    "New folder" : "Ny mapp",
    "Grid view" : "Rutnätsvy",
    "List view" : "Listvy",
    "Move selection" : "Flytta urval",
    "Delete selection" : "Radera urval",
    "Open all selected" : "Öppna alla markerade",
    "Select all" : "Välj alla",
    "Cancel selection" : "Avbryt markering",
    "Selected {folders} folders and {bookmarks} bookmarks" : "Valde {folders} mappar och {bookmarks} bokmärken",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Valde %n bokmärke","Valde %n bokmärken"],
    "Enter a link" : "Ange en länk",
    "Enter a title" : "Ange en titel",
    "Select folder" : "Välj mapp",
    "Enter folder title" : "Ange titel",
    "Shared by {user}" : "Delad av {user}",
    "Root folder" : "Topp-mapp",
    "Submit" : "Verkställ",
    "Cancel" : "Avbryt",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Flyttar %n mapp och några bokmärken","Flyttar %n mappar och några bokmärken"],
    "_Moving %n folder_::_Moving %n folders_" : ["Flyttar %n mapp","Flyttar %n mappar"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Flyttar %n bokmärke","Flyttar %n bokmärken"],
    "All bookmarks" : "Alla bokmärken",
    "Recent" : "Nya",
    "Archived" : "Arkiverad",
    "Broken links" : "Brutna länkar",
    "Filter tags" : "Filtrera taggar",
    "Untagged" : "Inte taggad",
    "{used} bookmarks of {available} available" : "{used} bokmärken av {available} tillgängliga",
    "No archived bookmarks" : "Inga arkiverade bokmärken",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Bokmärken till filer som foton eller PDF-filer sparas automatiskt i ditt Nextcloud så att du fortfarande kan hitta dem även när länken går offline.",
    "No bookmarks here" : "Inga bokmärken här",
    "Add a bookmark" : "Lägg till ett bokmärke",
    "Import bookmarks" : "Importera bokmärken",
    "Import" : "Importera",
    "Export" : "Exportera",
    "Sorting" : "Sortering",
    "Recently added" : "Nyligen tillagd",
    "Alphabetically" : "Alfabetisk",
    "Most visited" : "Mest besökta",
    "Last modified" : "Senast ändrad",
    "Custom order" : "Anpassad sortering",
    "Archive path" : "Sökväg till arkiv",
    "Enter the path of a folder where bookmarked files should be stored" : "Ange sökvägen till en mapp där bokmärkta filer ska lagras",
    "Client apps" : "Klientappar",
    "Also check out the collection of client apps that integrate with this app: " : "Kolla också in samlingen av klientappar som integrerar med den här appen: ",
    "Bookmarklet" : "Bookmarklet",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage" : "Dra till webbläsarens bokmärken och klicka på den för att snabbt bokmärka en webbplats",
    "Add to {instanceName}" : "Lägg till {instanceName}",
    "Clear data" : "Rensa data",
    "Permanently remove all bookmarks from your account." : "Ta bort alla bokmärken från ditt konto permanent.",
    "Delete all bookmarks" : "Ta bort alla bokmärken",
    "Do you really want to delete all your bookmarks?" : "Vill du verkligen radera alla dina bokmärken?",
    "Title" : "Titel",
    "Link" : "Länk",
    "Creation date" : "Skapat datum",
    "Tags" : "Taggar",
    "Select tags and create new ones" : "Välj taggar och skapa nya",
    "Attachments" : "Bilagor",
    "Archived version" : "Arkiverad version",
    "Open archived file" : "Öppna arkiverad fil",
    "Notes" : "Anteckning",
    "{time} ago" : "{time} sedan",
    "Owner" : "Ägare",
    "Sharing" : "Delning",
    "Select a user or group" : "Välj en användare eller grupp",
    "Share link" : "Dela länk",
    "Copy link" : "Kopiera länk",
    "Copy RSS feed" : "Kopiera RSS-flöde",
    "Delete link" : "Radera länk",
    "Create public link" : "Skapa offentlig länk",
    "Allow editing" : "Tillåt redigering",
    "Allow sharing" : "Tillåt delning",
    "Remove share" : "Ta bort delning",
    "Link copied" : "Länk kopierad",
    "RSS feed copied" : "Kopierade RSS flöde",
    "Select" : "Välj",
    "Previews" : "Förhandsvisningar",
    "In order to display real screenshots of your bookmarked websites, Bookmarks can use third-party services to generate previews." : "För att visa riktiga skärmdumpar av dina bokmärkta webbplatser kan appen använda tjänster från tredje part för att skapa förhandsvisningar.",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Du kan antingen registrera dig gratis på screeenly.com eller sätta upp en egen server.",
    "Screeenly API URL" : "Screeenly API-webbadress",
    "Screeenly API key" : "Screeenly API-nyckel",
    "Webshot" : "Webshot",
    "Webshot API URL" : "Webshot API URL",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "ScreenshotMachine API nyckel",
    "Pageres CLI" : "Pageres CLI",
    "Simply install the pageres cli on your server and bookmarks will find it." : "Installera pageres cli på din server och appen kommer att hitta den.",
    "Privacy" : "Integritet",
    "Bookmarks will try to access web pages that you add to automatically add information about them." : "Bokmärken kommer försöka komma åt webbsidor som du lägger till för att automatiskt lägga till information om dem.",
    "Enable accessing and collecting information from the web pages you add" : "Aktivera åtkomst till och samla information från webbsidorna du lägger till",
    "Performance" : "Prestanda",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "I en installation med många användare kan det vara nödvändigt att begränsa antalet bokmärken per konto.",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Maximalt tillåtet antal bokmärken per konto. (0 för ingen gräns; standard är ingen gräns)",
    "Failed to load settings" : "Kunde inte läsa in inställningar",
    "Failed to save settings" : "Kunde inte spara inställningarna",
    "This URL is already bookmarked! Overwrite?" : "Den här webbadressen är redan bokmärkt! Skriva över?",
    "Enter bookmark title" : "Ange titel",
    "Enter bookmark URL" : "Ange bokmärkets webbadress",
    "Folder" : "Mapp",
    "Root Folder" : "Rot mapp",
    "Save" : "Spara",
    "Failed to count unavailable bookmarks" : "Det gick inte att räkna otillgängliga bokmärken",
    "Failed to count archived bookmarks" : "Det gick inte att räkna arkiverade bokmärken",
    "Failed to load bookmark" : "Det gick inte att läsa in bokmärket",
    "Failed to find existing bookmark" : "Kunde inte hitta befintligt bokmärke",
    "Failed to create bookmark" : "Kunde inte skapa bokmärke",
    "Failed to save bookmark" : "Kunde inte spara bokmärke",
    "Failed to move bookmark" : "Kunde inte flytta bokmärke",
    "Failed to delete bookmark" : "Kunde inte radera bokmärke",
    "Failed to rename tag" : "Kunde inte döpa om tagg",
    "Failed to load tags" : "Kunde inte läsa in taggar",
    "Failed to load folders" : "Kunde inte läsa in mappar",
    "Failed to delete folder" : "Kunde inte radera mapp",
    "Failed to create folder" : "Kunde inte skapa mapp",
    "Failed to fetch bookmarks." : "Kunde inte hämta bokmärken.",
    "Failed to change setting" : "Kunde inte ändra inställning",
    "Failed to load setting {key}" : "Det gick inte att läsa in inställningen {key}",
    "Failed to update share {shareId}" : "Det gick inte att uppdatera delningen {shareId}",
    "Failed to delete share {shareId}" : "Det gick inte att radera delningen {shareId}",
    "Bookmarks feed" : "Bokmärkesflöde"
},
"nplurals=2; plural=(n != 1);");

==> v4.0.6.tar.gz: bookmarks/l10n/sv.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Bokmärken",
    "You bookmarked \"%s\"" : "Du sparade \"%s\"",
    "%1$s bookmarked \"%2$s\"" : "%1$s sparade \"%2$s\"",
    "Someone bookmarked \"%s\"" : "Någon sparade %s",
    "You deleted \"%s\"" : "Du raderade \"%s\"",
    "%1$s deleted \"%2$s\"" : "%1$s raderade \"%2$s\"",
    "Someone deleted \"%s\"" : "Någon raderade \"%s\"",
    "You created folder \"%s\"" : "Du skapade mappen \"%s\"",
    "%1$s created folder \"%2$s\"" : "%1$s skapade mappen \"%2$s\"",
    "Someone created folder \"%s\"" : "Någon skapade mappen \"%s\"",
    "You moved folder \"%s\"" : "Du flyttade mappen \"%s\"",
    "%1$s moved folder \"%2$s\"" : "%1$s flyttade mappen \"%2$s\"",
    "Someone moved folder \"%s\"" : "Någon flyttade mappen \"%s\"",
    "You deleted folder \"%s\"" : "Du raderade mappen \"%s\"",
    "%1$s deleted folder \"%2$s\"" : "%1$s raderade mappen \"%2$s\"",
    "Someone deleted folder \"%s\"" : "Någon raderade mappen \"%s\"",
    "You shared folder \"%1$s\" with %2$s" : "Du delade mappen \"%1$s\" med %2$s",
    "You shared folder \"%s\" with someone" : "Du delade mappen \"%s\" med någon",
    "%1$s shared folder \"%2$s\" with you" : "%1$s delade mappen \"%2$s\" med dig",
    "Someone shared folder \"%s\" with you" : "Någon delade mappen \"%s\" med dig",
    "You unshared folder \"%1$s\" with %2$s" : "Du slutade dela mappen \"%1$s\" med %2$s",
    "You unshared folder \"%s\" with someone" : "Du slutade dela mappen \"%s\" med någon",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s slutade dela mappen \"%2$s\" med dig",
    "Someone unshared folder \"%s\" with you" : "Någon slutade  dela mappen \"%s\" med dig",
    "No file provided for import" : "Inga filer given för importering",
    "Unsupported file type for import" : "Ogiltig filtyp för import",
    "Bookmarks shared by %s" : "Bokmärken delas av %s",
    "Recent Bookmarks" : "Senaste bokmärken",
    "Bookmark" : "Bokmärke",
    "Bookmark deleted" : "Bokmärke raderat",
    "Bookmark created" : "Bokmärke skapat",
    "Bookmark moved" : "Bokmärke flyttat",
    "Bookmark updated" : "Bokmärke uppdaterat",
    "Create bookmark" : "Skapa bokmärke",
    "Takes a link and adds it to your collection of bookmarks." : "Tar en länk och lägger till den i dina bokmärken.",
    "A Bookmark manager for Nextcloud" : "En bokmärkeshanterare för Nextcloud",
    "Enter new title" : "Ange ny titel",
    "Select bookmark" : "Välj bokmärke",
    "Details" : "Detaljer",
    "Rename" : "Byt namn",
    "Move" : "Flytta",
    "Delete" : "Ta bort",
    "Search" : "Sök",
    "Select one or more tags" : "Välj en eller flera taggar",
    "New" : "Nytt",
    "New bookmark" : "Nytt bokmärke",
    "New folder" : "Ny mapp",
    "Grid view" : "Rutnätsvy",
    "List view" : "Listvy",
    "Move selection" : "Flytta urval",
    "Delete selection" : "Ta bort urval",
    "Open all selected" : "Öppna alla markerade",
    "Select all" : "Välj alla",
    "Cancel selection" : "Avbryt markering",
    "Selected {folders} folders and {bookmarks} bookmarks" : "Valde {folders} mappar och {bookmarks} bokmärken",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Valde %n bokmärke","Valde %n bokmärken"],
    "Enter a link" : "Ange en länk",
    "Enter a title" : "Ange en titel",
    "Select folder" : "Välj mapp",
    "Enter folder title" : "Ange titel",
    "Shared by {user}" : "Delad av {user}",
    "Root folder" : "Topp-mapp",
    "Submit" : "Verkställ",
    "Cancel" : "Avbryt",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Flyttar %n mapp och några bokmärken","Flyttar %n mappar och några bokmärken"],
    "_Moving %n folder_::_Moving %n folders_" : ["Flyttar %n mapp","Flyttar %n mappar"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Flyttar %n bokmärke","Flyttar %n bokmärken"],
    "All bookmarks" : "Alla bokmärken",
    "Recent" : "Nya",
    "Archived" : "Arkiverad",
    "Broken links" : "Brutna länkar",
    "Filter tags" : "Filtrera taggar",
    "Untagged" : "Inte taggad",
    "{used} bookmarks of {available} available" : "{used} bokmärken av {available} tillgängliga",
    "No archived bookmarks" : "Inga arkiverade bokmärken",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Bokmärken till filer som foton eller PDF-filer sparas automatiskt i ditt Nextcloud så att du fortfarande kan hitta dem även när länken går offline.",
    "No bookmarks here" : "Inga bokmärken här",
    "Add a bookmark" : "Lägg till ett bokmärke",
    "Import bookmarks" : "Importera bokmärken",
    "Import" : "Importera",
    "Export" : "Exportera",
    "Sorting" : "Sortering",
    "Recently added" : "Nyligen tillagd",
    "Alphabetically" : "Alfabetisk",
    "Most visited" : "Mest besökta",
    "Last modified" : "Senast ändrad",
    "Custom order" : "Anpassad sortering",
    "Archive path" : "Sökväg till arkiv",
    "Enter the path of a folder where bookmarked files should be stored" : "Ange sökvägen till en mapp där bokmärkta filer ska lagras",
    "Client apps" : "Klientappar",
    "Also check out the collection of client apps that integrate with this app: " : "Kolla också in samlingen av klientappar som integrerar med den här appen: ",
    "Bookmarklet" : "Bookmarklet",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage" : "Dra till webbläsarens bokmärken och klicka på den för att snabbt bokmärka en webbplats",
    "Add to {instanceName}" : "Lägg till {instanceName}",
    "Clear data" : "Rensa data",
    "Permanently remove all bookmarks from your account." : "Ta bort alla bokmärken från ditt konto permanent.",
    "Delete all bookmarks" : "Ta bort alla bokmärken",
    "Do you really want to delete all your bookmarks?" : "Vill du verkligen radera alla dina bokmärken?",
    "Title" : "Titel",
    "Link" : "Länk",
    "Creation date" : "Skapat datum",
    "Tags" : "Taggar",
    "Select tags and create new ones" : "Välj taggar och skapa nya",
    "Attachments" : "Bilagor",
    "Archived version" : "Arkiverad version",
    "Open archived file" : "Öppna arkiverad fil",
    "Notes" : "Anteckning",
    "{time} ago" : "{time} sedan",
    "Owner" : "Ägare",
    "Sharing" : "Delning",
    "Select a user or group" : "Välj en användare eller grupp",
    "Share link" : "Dela länk",
    "Copy link" : "Kopiera länk",
    "Copy RSS feed" : "Kopiera RSS-flöde",
    "Delete link" : "Ta bort länk",
    "Create public link" : "Skapa offentlig länk",
    "Allow editing" : "Tillåt redigering",
    "Allow sharing" : "Tillåt delning",
    "Remove share" : "Ta bort delning",
    "Link copied" : "Länk kopierad",
    "RSS feed copied" : "Kopierade RSS flöde",
    "Select" : "Välj",
    "Previews" : "Förhandsvisningar",
    "In order to display real screenshots of your bookmarked websites, Bookmarks can use third-party services to generate previews." : "För att visa riktiga skärmdumpar av dina bokmärkta webbplatser kan appen använda tjänster från tredje part för att skapa förhandsvisningar.",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Du kan antingen registrera dig gratis på screeenly.com eller sätta upp en egen server.",
    "Screeenly API URL" : "Screeenly API-webbadress",
    "Screeenly API key" : "Screeenly API-nyckel",
    "Webshot" : "Webshot",
    "Webshot API URL" : "Webshot API URL",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "ScreenshotMachine API nyckel",
    "Pageres CLI" : "Pageres CLI",
    "Simply install the pageres cli on your server and bookmarks will find it." : "Installera pageres cli på din server och appen kommer att hitta den.",
    "Privacy" : "Integritet",
    "Bookmarks will try to access web pages that you add to automatically add information about them." : "Bokmärken kommer försöka komma åt webbsidor som du lägger till för att automatiskt lägga till information om dem.",
    "Enable accessing and collecting information from the web pages you add" : "Aktivera åtkomst till och samla information från webbsidorna du lägger till",
    "Performance" : "Prestanda",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "I en installation med många användare kan det vara nödvändigt att begränsa antalet bokmärken per konto.",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Maximalt tillåtet antal bokmärken per konto. (0 för ingen gräns; standard är ingen gräns)",
    "Failed to load settings" : "Kunde inte läsa in inställningar",
    "Failed to save settings" : "Kunde inte spara inställningarna",
    "This URL is already bookmarked! Overwrite?" : "Den här webbadressen är redan bokmärkt! Skriva över?",
    "Enter bookmark title" : "Ange titel",
    "Enter bookmark URL" : "Ange bokmärkets webbadress",
    "Folder" : "Mapp",
    "Root Folder" : "Rot mapp",
    "Save" : "Spara",
    "Failed to count unavailable bookmarks" : "Det gick inte att räkna otillgängliga bokmärken",
    "Failed to count archived bookmarks" : "Det gick inte att räkna arkiverade bokmärken",
    "Failed to load bookmark" : "Det gick inte att läsa in bokmärket",
    "Failed to find existing bookmark" : "Kunde inte hitta befintligt bokmärke",
    "Failed to create bookmark" : "Kunde inte skapa bokmärke",
    "Failed to save bookmark" : "Kunde inte spara bokmärke",
    "Failed to move bookmark" : "Kunde inte flytta bokmärke",
    "Failed to delete bookmark" : "Kunde inte radera bokmärke",
    "Failed to rename tag" : "Kunde inte döpa om tagg",
    "Failed to load tags" : "Kunde inte läsa in taggar",
    "Failed to load folders" : "Kunde inte läsa in mappar",
    "Failed to delete folder" : "Kunde inte radera mapp",
    "Failed to create folder" : "Kunde inte skapa mapp",
    "Failed to fetch bookmarks." : "Kunde inte hämta bokmärken.",
    "Failed to change setting" : "Kunde inte ändra inställning",
    "Failed to load setting {key}" : "Det gick inte att läsa in inställningen {key}",
    "Failed to update share {shareId}" : "Det gick inte att uppdatera delningen {shareId}",
    "Failed to delete share {shareId}" : "Det gick inte att radera delningen {shareId}",
    "Bookmarks feed" : "Bokmärkesflöde"
},
"nplurals=2; plural=(n != 1);");
